@@ -1,6 +1,7 @@
 package GitLab::API::v4::Config;
-
-$GitLab::API::v4::Config::VERSION = '0.16';
+use 5.010001;
+use strictures 2;
+our $VERSION = '0.17';
 
 =encoding utf8
 
@@ -36,7 +37,6 @@ use Getopt::Long;
 use IO::Prompter;
 
 use Moo;
-use strictures 2;
 use namespace::clean;
 
 sub _filter_args {
