@@ -1,5 +1,8 @@
 package GitLab::API::v4::Constants;
-$GitLab::API::v4::Constants::VERSION = '0.15';
+use 5.010001;
+use strictures 2;
+our $VERSION = '0.17';
+
 =encoding utf8
 
 =head1 NAME
@@ -16,7 +19,6 @@ GitLab::API::v4::Constants - GitLab API v4 constants.
 
 use Const::Fast;
 
-use strictures 2;
 use namespace::clean;
 
 use Exporter qw( import );
