@@ -1,5 +1,8 @@
 package GitLab::API::v4::Paginator;
-$GitLab::API::v4::Paginator::VERSION = '0.15';
+use 5.010001;
+use strictures 2;
+our $VERSION = '0.17';
+
 =encoding utf8
 
 =head1 NAME
@@ -19,7 +22,6 @@ use Types::Common::String -types;
 use Carp qw( croak );
 
 use Moo;
-use strictures 2;
 use namespace::clean;
 
 =head1 REQUIRED ARGUMENTS
