@@ -1,5 +1,8 @@
 package GitLab::API::v4::RESTClient;
-$GitLab::API::v4::RESTClient::VERSION = '0.14';
+use 5.010001;
+use strictures 2;
+our $VERSION = '0.17';
+
 =encoding utf8
 
 =head1 NAME
@@ -31,7 +34,6 @@ use Try::Tiny;
 use Path::Tiny;
 
 use Moo;
-use strictures 2;
 use namespace::clean;
 
 has _clean_base_url => (
